# Parameters from TOML

## What it does
Reads a TOML parameters file name and returns a parameters dictionary.

## Inputs
### parameters_file_name
A string containing the path and name of a TOML file.
## Output

###

## Examples

###

## Tests

###


## Ope issues
